@@ -56,8 +56,12 @@ void ChangeRecorder::setConfig(QSettings * settings)
 void ChangeRecorder::replayNext()
 {
   Q_D( ChangeRecorder );
+
+  if ( !d->enableChangeRecording )
+    return;
+
   if ( !d->pendingNotifications.isEmpty() ) {
-    const NotificationMessage msg = d->pendingNotifications.head();
+    const NotificationMessageV2 msg = d->pendingNotifications.head();
     if ( d->ensureDataAvailable( msg ) ) {
       d->emitNotification( msg );
     } else if ( d->translateAndCompress( d->pipeline, msg ) ) {
@@ -88,6 +92,9 @@ void ChangeRecorder::changeProcessed()
 {
   Q_D( ChangeRecorder );
 
+  if ( !d->enableChangeRecording )
+    return;
+
   // changerecordertest.cpp calls changeProcessed after receiving nothingToReplay,
   // so test for emptiness. Not sure real code does this though.
   // Q_ASSERT( !d->pendingNotifications.isEmpty() )
