@@ -29,6 +29,8 @@
 
 #include <kcolorscheme.h>
 #include <klocale.h>
+#include <klocalizedstring.h>
+#include <kglobal.h>
 #include <kpushbutton.h>
 #include <ktextbrowser.h>
 
