@@ -101,7 +101,6 @@ class AddressTypeDialog : public KDialog
     KABC::Address::TypeList mTypeList;
 };
 
-
 AddressSelectionWidget::AddressSelectionWidget( QWidget *parent )
   : KComboBox( parent )
 {
@@ -149,8 +148,6 @@ void AddressSelectionWidget::updateView()
   }
 }
 
-
-
 AddressTypeCombo::AddressTypeCombo( QWidget *parent )
   : KComboBox( parent ),
     mType( KABC::Address::Home ),
@@ -231,18 +228,23 @@ void AddressTypeCombo::otherSelected()
   update();
 }
 
-
 AddressEditWidget::AddressEditWidget( QWidget *parent )
   : QWidget( parent ), mReadOnly( false )
 {
-  QGridLayout *layout = new QGridLayout( this );
+  QGridLayout *layout = new QGridLayout;
   layout->setSpacing( KDialog::spacingHint() );
   layout->setMargin( 0 );
 
+  QHBoxLayout *hboxLayout = new QHBoxLayout;
+  QLabel *label = new QLabel( i18nc( "@label:listbox type of address", "Address type:" ), this );
+  hboxLayout->addWidget( label );
+
   mAddressSelectionWidget = new AddressSelectionWidget( this );
   connect( mAddressSelectionWidget, SIGNAL(selectionChanged(KABC::Address)),
            SLOT(updateAddressView()) );
-  layout->addWidget( mAddressSelectionWidget, 0, 0, 1, 3 );
+  label->setBuddy( mAddressSelectionWidget );
+  hboxLayout->addWidget( mAddressSelectionWidget, 1 );
+  layout->addLayout( hboxLayout, 0, 0, 1, 3 );
 
   mAddressView = new QLabel( this );
   mAddressView->setFrameStyle( QFrame::StyledPanel | QFrame::Sunken );
@@ -252,17 +254,17 @@ AddressEditWidget::AddressEditWidget( QWidget *parent )
   mAddressView->setTextInteractionFlags( Qt::TextSelectableByKeyboard | Qt::TextSelectableByMouse );
   layout->addWidget( mAddressView, 1, 0, 1, 3 );
 
-  mCreateButton = new QPushButton( i18nc( "street/postal", "New..." ), this );
+  mCreateButton = new QPushButton( i18nc( "@action:button street/postal", "New..." ), this );
   connect( mCreateButton, SIGNAL(clicked()), this, SLOT(createAddress()) );
-  mEditButton = new QPushButton( i18nc( "street/postal", "Edit..." ), this );
+  mEditButton = new QPushButton( i18nc( "@action:button street/postal", "Edit..." ), this );
   connect( mEditButton, SIGNAL(clicked()), this, SLOT(editAddress()) );
-  mDeleteButton = new QPushButton( i18nc( "street/postal", "Delete" ), this );
+  mDeleteButton = new QPushButton( i18nc( "@action:button street/postal", "Delete" ), this );
   connect( mDeleteButton, SIGNAL(clicked()), this, SLOT(deleteAddress()) );
 
   layout->addWidget( mCreateButton, 2, 0 );
   layout->addWidget( mEditButton, 2, 1 );
   layout->addWidget( mDeleteButton, 2, 2 );
-
+  setLayout(layout);
   updateButtons();
 }
 
@@ -272,14 +274,18 @@ AddressEditWidget::~AddressEditWidget()
 
 void AddressEditWidget::setReadOnly( bool readOnly )
 {
-  mReadOnly = readOnly;
-  updateButtons();
+    if (mReadOnly != readOnly) {
+        mReadOnly = readOnly;
+        updateButtons();
+    }
 }
 
 void AddressEditWidget::updateName( const QString &name )
 {
-  mName = name;
-  updateAddressView();
+    if (mName != name) {
+        mName = name;
+        updateAddressView();
+    }
 }
 
 void AddressEditWidget::createAddress()
@@ -392,7 +398,6 @@ void AddressEditWidget::storeContact( KABC::Addressee &contact ) const
   }
 }
 
-
 AddressEditDialog::AddressEditDialog( QWidget *parent )
   : KDialog(parent)
 {
@@ -408,10 +413,14 @@ AddressEditDialog::AddressEditDialog( QWidget *parent )
   topLayout->setSpacing( spacingHint() );
   topLayout->setMargin( 0 );
 
-  mTypeCombo = new AddressTypeCombo( page );
-  topLayout->addWidget( mTypeCombo, 0, 0, 1, 2 );
+  QLabel *label = new QLabel( i18nc( "@label:listbox type of address", "Address type:" ), this );
+  topLayout->addWidget( label, 0, 0 );
 
-  QLabel *label = new QLabel( i18nc( "<streetLabel>:", "%1:", KABC::Address::streetLabel() ), page );
+  mTypeCombo = new AddressTypeCombo( page );
+  label->setBuddy( mTypeCombo );
+  topLayout->addWidget( mTypeCombo, 0, 1 );
+
+  label = new QLabel( i18nc( "<streetLabel>:", "%1:", KABC::Address::streetLabel() ), page );
   label->setAlignment( Qt::AlignTop | Qt::AlignLeft );
   topLayout->addWidget( label, 1, 0 );
   mStreetTextEdit = new KTextEdit( page );
@@ -549,7 +558,6 @@ void AddressEditDialog::fillCountryCombo()
   mCountryCombo->setCurrentIndex( mCountryCombo->findText( currentCountry ) );
 }
 
-
 AddressTypeDialog::AddressTypeDialog( KABC::Address::Type type, QWidget *parent )
   : KDialog( parent)
 {
