@@ -48,7 +48,7 @@ class AddressSelectionWidget : public KComboBox
      *
      * @param parent The parent widget.
      */
-    AddressSelectionWidget( QWidget *parent = 0 );
+    explicit AddressSelectionWidget( QWidget *parent = 0 );
 
     /**
      * Destroys the address selection widget.
@@ -57,11 +57,13 @@ class AddressSelectionWidget : public KComboBox
 
     /**
      * Sets the list of @p addresses that can be chosen from.
+     * @param addresses list of addresses that can be chosen from
      */
     void setAddresses( const KABC::Address::List &addresses );
 
     /**
      * Sets the current @p address.
+     * @param address new current address
      */
     void setCurrentAddress( const KABC::Address &address );
 
@@ -101,7 +103,7 @@ class AddressTypeCombo : public KComboBox
      *
      * @param parent The parent widget.
      */
-    AddressTypeCombo( QWidget *parent = 0 );
+    explicit AddressTypeCombo( QWidget *parent = 0 );
 
     /**
      * Destroys the address type combo.
@@ -110,6 +112,7 @@ class AddressTypeCombo : public KComboBox
 
     /**
      * Sets the type that shall be selected in the combobox.
+     * @param type KABC address type to set.
      */
     void setType( KABC::Address::Type type );
 
@@ -179,7 +182,7 @@ class AddressEditDialog : public KDialog
   Q_OBJECT
 
   public:
-    AddressEditDialog( QWidget *parent = 0 );
+    explicit AddressEditDialog( QWidget *parent = 0 );
     ~AddressEditDialog();
 
     void setAddress( const KABC::Address &address );
