@@ -39,7 +39,7 @@
 class KJob;
 
 typedef QList<Akonadi::Entity::Id> EntityIdList;
-Q_DECLARE_METATYPE( EntityIdList )
+Q_DECLARE_METATYPE(QList<Akonadi::Entity::Id>)
 
 namespace Akonadi {
 
@@ -441,7 +441,7 @@ private:
       // make sure we find this node again if something went wrong here,
       // most likely the object got deleted from the server in the meantime
       if ( !result.isValid() ) {
-        node->entity = Item( id );
+        node->entity = T( id );
         node->invalid = true;
       } else {
         node->entity = result;
@@ -453,7 +453,6 @@ private:
 
   void extractResults( KJob* job, typename T::List &entities ) const;
 
-
 private:
   QHash< Entity::Id, EntityListCacheNode<T>* > mCache;
   int mCapacity;
