@@ -175,7 +175,6 @@ ItemFetchJob::ItemFetchJob(const QList<Akonadi::Item::Id>& items, QObject* paren
     d->mRequestedItems.append(Item(id));
 }
 
-
 ItemFetchJob::~ItemFetchJob()
 {
 }
@@ -231,6 +230,13 @@ Item::List ItemFetchJob::items() const
   return d->mResultItems;
 }
 
+void ItemFetchJob::clearItems()
+{
+  Q_D( ItemFetchJob );
+
+  d->mResultItems.clear();
+}
+
 void ItemFetchJob::setFetchScope( ItemFetchScope &fetchScope )
 {
   Q_D( ItemFetchJob );
@@ -259,5 +265,4 @@ void ItemFetchJob::setCollection(const Akonadi::Collection& collection)
   d->mCollection = collection;
 }
 
-
 #include "moc_itemfetchjob.cpp"
