@@ -50,7 +50,6 @@
 
 using namespace Akonadi;
 
-
 //@cond PRIVATE
 
 void SessionPrivate::startNext()
@@ -195,7 +194,7 @@ void SessionPrivate::dataReceived()
       // handle login response
       if ( parser->tag() == QByteArray( "0" ) ) {
         if ( parser->data().startsWith( "OK" ) ) { //krazy:exclude=strings
-          writeData("1 CAPABILITY (NOTIFY 2)");
+          writeData("1 CAPABILITY (NOTIFY 2 NOPAYLOADPATH)");
         } else {
           kWarning() << "Unable to login to Akonadi server:" << parser->data();
           socket->close();
@@ -359,7 +358,6 @@ void SessionPrivate::itemRevisionChanged( Akonadi::Item::Id itemId, int oldRevis
 
 //@endcond
 
-
 SessionPrivate::SessionPrivate( Session *parent )
     : mParent( parent ), socket( 0 ), protocolVersion( 0 ), currentJob( 0 ), parser( 0 )
 {
@@ -401,7 +399,6 @@ void SessionPrivate::forceReconnect()
   QMetaObject::invokeMethod( mParent, "reconnect", Qt::QueuedConnection ); // avoids reconnecting in the dtor
 }
 
-
 Session::Session(const QByteArray & sessionId, QObject * parent) :
     QObject( parent ),
     d( new SessionPrivate( this ) )
