@@ -19,7 +19,7 @@
 
 #include "logoutjob.h"
 
-#include <KDE/KLocale>
+#include <KDE/KLocalizedString>
 
 #include "job_p.h"
 #include "message_p.h"
@@ -56,4 +56,3 @@ void LogoutJob::connectionLost()
 {
   emitResult();
 }
-
