@@ -33,14 +33,14 @@ class TransportListView : public QTreeWidget
   Q_OBJECT
 
   public:
-    TransportListView( QWidget *parent = 0 );
+    explicit TransportListView( QWidget *parent = 0 );
     //virtual ~TransportListView() {}
 
     // overloaded from QTreeWidget
     void editItem( QTreeWidgetItem *item, int column = 0 );
 
   protected slots:
-    virtual void commitData( QWidget *editor );
+    void commitData( QWidget *editor );
 
   private slots:
     void fillTransportList();
